@@ -9,7 +9,7 @@ use std::collections::BTreeSet;
 
 use pretty_assertions::assert_eq;
 use stack_graphs::c::sg_forward_partial_path_stitcher_free;
-use stack_graphs::c::sg_forward_partial_path_stitcher_new;
+use stack_graphs::c::sg_forward_partial_path_stitcher_from_nodes;
 use stack_graphs::c::sg_forward_partial_path_stitcher_process_next_phase;
 use stack_graphs::c::sg_forward_partial_path_stitcher_set_max_work_per_phase;
 use stack_graphs::c::sg_partial_path;
@@ -128,7 +128,7 @@ fn check_jump_to_definition(graph: &TestGraph, file: &str, expected_partial_path
     });
 
     // Create the forward partial path stitcher.
-    let stitcher = sg_forward_partial_path_stitcher_new(
+    let stitcher = sg_forward_partial_path_stitcher_from_nodes(
         graph.graph,
         partials,
         db,
